==> m-tx_0.30a.orig.tar.gz: m-tx-0.30a.orig/doc/netsoos0.ex <==
%%%%%%%%%%%%%%%%%
%
% netsoos0.tex
%
%%%%%%%%%%%%%%%%
\normalmusicsize%
\tracingstats=2\relax
\hsize=539pt
\vsize=740pt
\def\nbinstruments{2}
\setstaffs11
\setclef16
\setname1{ }
\setstaffs21
\setclef20
\setname2{ }
\generalsignature{ 2}%
\generalmeter{\meterfrac{3}{4}}%
\parindent 0pt
\elemskip1pt\afterruleskip1.000pt\beforeruleskip0pt\relax
\stafftopmarg0pt\staffbotmarg5\Interligne\interstaff{10}\relax
\setinterinstrument1{9\Interligne}%
\grouptop12\groupbottom11%
\setsize2{\normalvalue}%
\setsongraise2{0\internote}%
\startpiece\addspace\afterruleskip%            
\setlyrics{21}{Net soos ek is, geen hulp na-by, al-leen U bloed ge-stort vir my,}%
\setlyrics{22}{Net soos ek is, nooi U vir my, ver-ge-we, rei-nig en be-vry.}%
\setlyrics{23}{Net soos ek is, U lief-de teer werp al-le hin-der-pa-le neer.}%
\assignlyrics2{21,22,23}%
\auxlyr{\assignlyrics2{}}%
\assignlyrics1{}%
\auxlyr{\assignlyrics1{}}%
\znotes&\zcharnote{16}{\titles{2.0}{}{0}%
{Net soos ek is}{2.0}{Charlotte Elliott}{2.0}}\en%
% bar  1
\def\NOTes{\vnotes2.83\elemskip}%
\def\NOTesp{\vnotes3.46\elemskip}%
\def\NOTEs{\vnotes4.00\elemskip}%
\def\NOTEsp{\vnotes4.90\elemskip}%
\NOTes\ql{'D}\ql D\ql D\nextvoice\qu{''A}\qu A\qu A&\ql d\ql d\ql d%
\nextvoice\nolyr\qu f\nolyr\qu f\nolyr\qu f\en%
% bar  2
\xbar
\NOTEs\hl{'D}\nextvoice\bigsh{'G}\hu G&\roff{\hl d}\nextvoice\nolyr%
\bigsh e\hu e\en%
\NOTes\ql{'D}\nextvoice\qu{'G}&\roff{\ql d}\nextvoice\nolyr\qu e\en%
% bar  3
\xbar
\NOTEs\hl{'D}\nextvoice\hu{''A}&\hl d\nextvoice\nolyr\hu f\en%
\NOTes\ql{'G}\nextvoice\qu{'G}&\ql d\nextvoice\nolyr\qu{'b}\en%
% bar  4
\xbar
\NOTEsp\hlp{'F}\nextvoice\hup{''A}&\hlp d\nextvoice\nolyr\hup{'a}\en%
% bar  5
\xbar
\NOTes\ql{'E}\ql E\ql E\nextvoice\qu{''B}\qu B\qu B&\ql e\ql e\ql e%
\nextvoice\nolyr\qu g\nolyr\qu g\nolyr\qu g\en%
% bar  6
\xbar
\NOTEs\hl{''A}\nextvoice\bigna{''C}\hu C&\bigsh d\hl d\nextvoice\nolyr%
\hu f\en%
\NOTes\ql{''A}\nextvoice\qu{''C}&\ql d\nextvoice\nolyr\qu f\en%
% bar  7
\xbar
\NOTEs\hl{'G}\nextvoice\hu{''B}&\hl e\nextvoice\nolyr\hu g\en%
\NOTes\ql{'G}\nextvoice\qu{''E}&\ql f\nextvoice\nolyr\bigna{'c}\qu c\en%
\let\Endpiece=\endpiece%
% bar  8
\xbar
\NOTEsp\hlp{''B}\nextvoice\bigsh{''D}\hup D&\hlp f\nextvoice\nolyr%
\hup{'b}\en%
\Endpiece

==> m-tx_0.52.orig.tar.gz: m-tx-0.52/doc/netsoos0.ex <==
%%%%%%%%%%%%%%%%%
%
% netsoos0.tex
%
%%%%%%%%%%%%%%%%
\def\Lrp#1{\centerbar{\liftpause{#1}}}
\normalmusicsize%
\tracingstats=2\relax
\hsize=539pt
\vsize=740pt
\def\nbinstruments{2}
\setstaffs11
\setclef16
\setname1{ }
\setstaffs21
\setclef20
\setname2{ }
\generalsignature{ 2}%
\generalmeter{\meterfrac{3}{4}}%
\parindent 0pt
\elemskip1pt\afterruleskip1.000pt\beforeruleskip0pt\relax
\stafftopmarg0pt\staffbotmarg5\Interligne\interstaff{10}\relax
\setinterinstrument1{9\Interligne}%
\grouptop12\groupbottom11%
\startpiece\addspace\afterruleskip%
\setlyrics{21}{Net soos ek is, geen hulp na-by, al-leen U bloed ge-stort vir my,}%
\setlyrics{22}{Net soos ek is, nooi U vir my, ver-ge-we, rei-nig en be-vry.}%
\setlyrics{23}{Net soos ek is, U lief-de teer werp al-le hin-der-pa-le neer.}%
\assignlyrics2{21,22,23}%
\znotes&\zcharnote{16}{\titles{2.0}{}{0}%
{Net soos ek is}{2.0}{Charlotte Elliott}{2.0}}\en%
% bar  1
\def\NOTes{\vnotes2.83\elemskip}%
\def\NOTEs{\vnotes4.00\elemskip}%
\def\NOTEsp{\vnotes4.90\elemskip}%
\NOTes\ql{'D}\ql D\ql D\nextvoice\qu{''A}\qu A\qu A&\ql d\ql d\ql d%
\nextvoice\qu f\qu f\qu f\en%
% bar  2
\xbar
\NOTEs\hl{'D}\nextvoice\bigsh{'G}\hu G&\roff{\hl d}\nextvoice\bigsh e%
\hu e\en%
\NOTes\ql{'D}\nextvoice\qu{'G}&\roff{\ql d}\nextvoice\qu e\en%
% bar  3
\xbar
\NOTEs\hl{'D}\nextvoice\hu{''A}&\hl d\nextvoice\hu f\en%
\NOTes\ql{'G}\nextvoice\qu{'G}&\ql d\nextvoice\qu{'b}\en%
% bar  4
\xbar
\NOTEsp\hlp{'F}\nextvoice\hup{''A}&\hlp d\nextvoice\hup{'a}\en%
% bar  5
\xbar
\NOTes\ql{'E}\ql E\ql E\nextvoice\qu{''B}\qu B\qu B&\ql e\ql e\ql e%
\nextvoice\qu g\qu g\qu g\en%
% bar  6
\xbar
\NOTEs\hl{''A}\nextvoice\bigna{''C}\hu C&\bigsh d\hl d\nextvoice\hu f\en%
\NOTes\ql{''A}\nextvoice\qu{''C}&\ql d\nextvoice\qu f\en%
% bar  7
\xbar
\NOTEs\hl{'G}\nextvoice\hu{''B}&\hl e\nextvoice\hu g\en%
\NOTes\ql{'G}\nextvoice\qu{''E}&\ql f\nextvoice\bigna{'c}\qu c\en%
\let\Endpiece=\endpiece%
% bar  8
\xbar
\NOTEsp\hlp{''B}\nextvoice\bigsh{''D}\hup D&\hlp f\nextvoice\hup{'b}\en%
\Endpiece
